import { Switch, Route, useLocation } from "wouter";
import { queryClient } from "./lib/queryClient";
import { QueryClientProvider } from "@tanstack/react-query";
import { Toaster } from "@/components/ui/toaster";
// import { TooltipProvider } from "@/components/ui/tooltip";
import { PerformanceMonitor } from "@/components/performance-monitor";
import CookieBanner from "@/components/CookieBanner";
import { lazy, Suspense, useEffect } from "react";
import { initFacebookPixel } from "./lib/facebook-pixel";

// Lazy load pages
const HomePage = lazy(() => import("./pages/home"));
const AboutPage = lazy(() => import("./pages/about"));
const ContactPage = lazy(() => import("./pages/contact"));
const SalesPage = lazy(() => import("./pages/sales"));
const BuyPage = lazy(() => import("./pages/buy"));
const RentPage = lazy(() => import("./pages/rent"));
const LandlordsPage = lazy(() => import("./pages/landlords"));
const TenantRegistrationPage = lazy(() => import("./pages/tenant-registration"));
const TenantApplicationPage = lazy(() => import("./pages/tenant-application"));
const MaintenanceRequestPage = lazy(() => import("./pages/maintenance-request"));
const PrivacyPolicyPage = lazy(() => import("./pages/privacy-policy"));
const BlogPage = lazy(() => import("./pages/blog"));
const BlogPostPage = lazy(() => import("./pages/blog-post"));
const BlogSubmitPage = lazy(() => import("./pages/blog-submit"));
const BlogMigratePage = lazy(() => import("./pages/blog-migrate"));
const InstantValuationPage = lazy(() => import("./pages/instant-valuation"));
const SalesOfferPage = lazy(() => import("./pages/sales-offer"));
const PropertyDetailPage = lazy(() => import("./pages/property-detail"));
const MortgagesPage = lazy(() => import("./pages/mortgages"));
const CardiffPage = lazy(() => import("./pages/cardiff"));
const CardiffPropertiesPage = lazy(() => import("./pages/cardiff-properties"));
const PropertiesPage = lazy(() => import("./pages/properties"));
const TermsPage = lazy(() => import("./pages/terms"));
const CookiesPage = lazy(() => import("./pages/cookies"));
const CommercialPage = lazy(() => import("./pages/commercial"));
const NotFound = lazy(() => import("./pages/not-found"));

function Router() {
  const [location] = useLocation();

  useEffect(() => {
    // Handle scroll behavior for navigation
    const hasHash = window.location.hash;
    
    if (hasHash) {
      // If there's a hash, scroll to the element after a brief delay
      setTimeout(() => {
        const element = document.getElementById(hasHash.substring(1));
        if (element) {
          element.scrollIntoView({ behavior: 'smooth' });
        }
      }, 100);
    } else {
      // No hash, scroll to top
      window.scrollTo(0, 0);
    }
  }, [location]);

  return (
    <Switch>
      <Route path="/" component={HomePage} />
      <Route path="/about" component={AboutPage} />
      <Route path="/contact" component={ContactPage} />
      <Route path="/sales" component={SalesPage} />
      <Route path="/buy" component={BuyPage} />
      <Route path="/rent" component={RentPage} />
      <Route path="/landlords" component={LandlordsPage} />
      <Route path="/mortgages" component={MortgagesPage} />
      <Route path="/commercial" component={CommercialPage} />
      <Route path="/properties" component={PropertiesPage} />
      <Route path="/cardiff" component={CardiffPage} />
      <Route path="/cardiff/properties" component={CardiffPropertiesPage} />
      <Route path="/tenant-registration" component={TenantRegistrationPage} />
      <Route path="/apply" component={TenantApplicationPage} />
      <Route path="/maintenance" component={MaintenanceRequestPage} />
      <Route path="/privacy-policy" component={PrivacyPolicyPage} />
      <Route path="/terms" component={TermsPage} />
      <Route path="/cookies" component={CookiesPage} />
      <Route path="/instant-valuation" component={InstantValuationPage} />
      <Route path="/sales-offer" component={SalesOfferPage} />
      <Route path="/property/:id" component={PropertyDetailPage} />
      <Route path="/blog-submit" component={BlogSubmitPage} />
      <Route path="/blog/submit" component={BlogSubmitPage} />
      <Route path="/blog/migrate" component={BlogMigratePage} />
      <Route path="/blog-migrate" component={BlogMigratePage} />
      <Route path="/blog/:id" component={BlogPostPage} />
      <Route path="/blog" component={BlogPage} />
      <Route component={NotFound} />
    </Switch>
  );
}

function App() {
  // Initialize Facebook Pixel when app loads
  useEffect(() => {
    if (!import.meta.env.VITE_FB_PIXEL_ID) {
      console.warn('Missing Facebook Pixel ID: VITE_FB_PIXEL_ID');
    } else {
      initFacebookPixel();
    }
  }, []);

  return (
    <QueryClientProvider client={queryClient}>
      <PerformanceMonitor />
      <Toaster />
      {/* <CookieBanner /> - Temporarily disabled to fix React hooks error */}
      <Suspense fallback={<div className="loading-spinner"></div>}>
        <Router />
      </Suspense>
    </QueryClientProvider>
  );
}

export default App;